@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# coding=utf-8
 # Copyright 2023 The HuggingFace Inc. team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,6 +12,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 
+# /// script
+# dependencies = [
+#     "transformers==4.55.4",
+#     "torch>=1.5.0",
+#     "torchvision>=0.6.0",
+#     "datasets>=1.8.0",
+# ]
+# ///
+
 import argparse
 import logging
 import math
@@ -53,7 +61,7 @@ Any model supported by the AutoModelForMaskedImageModeling API can be used.
 logger = logging.getLogger(__name__)
 
 # Will error if the minimal version of Transformers is not installed. Remove at your own risks.
-check_min_version("4.51.0")
+check_min_version("4.55.0")
 
 require_version("datasets>=1.8.0", "To fix: pip install -r examples/pytorch/image-pretraining/requirements.txt")
 
@@ -192,7 +200,7 @@ def parse_args():
         default=None,
         help=(
             "The token to use as HTTP bearer authorization for remote files. If not specified, will use the token "
-            "generated when running `huggingface-cli login` (stored in `~/.huggingface`)."
+            "generated when running `hf auth login` (stored in `~/.huggingface`)."
         ),
     )
     parser.add_argument(
@@ -444,7 +452,7 @@ def main():
     )
 
     # If we don't have a validation split, split off a percentage of train as validation.
-    args.train_val_split = None if "validation" in ds.keys() else args.train_val_split
+    args.train_val_split = None if "validation" in ds else args.train_val_split
     if isinstance(args.train_val_split, float) and args.train_val_split > 0.0:
         split = ds["train"].train_test_split(args.train_val_split)
         ds["train"] = split["train"]
@@ -779,9 +787,6 @@ def main():
                 output_dir = os.path.join(args.output_dir, output_dir)
             accelerator.save_state(output_dir)
 
-    if args.with_tracking:
-        accelerator.end_training()
-
     if args.output_dir is not None:
         accelerator.wait_for_everyone()
         unwrapped_model = accelerator.unwrap_model(model)
@@ -799,6 +804,9 @@ def main():
                     token=args.hub_token,
                 )
 
+    accelerator.wait_for_everyone()
+    accelerator.end_training()
+
 
 if __name__ == "__main__":
     main()
