@@ -30,108 +30,6 @@ TRANSFORMERS_PATH = Path(__file__).parent.parent
 REPO_PATH = TRANSFORMERS_PATH.parent.parent
 
 
-def add_import_structure_entry_init(content: str, fast_image_processor_name: str, model_name: str):
-    """
-    Add an entry to the `_import_structure` dictionary in the `__init__.py` file of the transformers package.
-    """
-    # Step 1: Find the block
-    block_regex = re.compile(
-        r"if not is_torchvision_available\(\):.*?else:\s*(\n(?P<indent>\s+)_import_structure\[.*?\].*?\n(?:\s*(?P=indent)_import_structure\[.*?\].*?\n)*)",
-        re.DOTALL,
-    )
-    match = block_regex.search(content)
-
-    if not match:
-        raise ValueError("Couldn't find the '_import_structure' block.")
-
-    # Capture the block content and indentation
-    block_content = match.group(1)
-    indent = match.group("indent")
-
-    # Step 2: Parse existing entries
-    lines = block_content.strip().split("\n")
-    entries = []
-
-    import_structure_header = indent + lines[0]
-    entries = lines[1:]
-
-    # Add the new entry, maintaining alphabetical order
-    new_entry = f'{indent}_import_structure["models.{model_name}"].append("{fast_image_processor_name}")'
-    if new_entry not in entries:
-        entries.append(new_entry)
-
-    entries.sort()
-    entries = [import_structure_header] + entries
-
-    # Step 3: Reconstruct the block
-    updated_block = "\n".join(entry for entry in entries)
-
-    # Replace the original block in the content
-    updated_content = content[: match.start(1)] + "\n" + updated_block + "\n" + content[match.end(1) :]
-
-    return updated_content
-
-
-def add_import_statement_init(content: str, fast_image_processor_name: str, model_name: str):
-    """
-    Add an import statement to the `__init__.py` file of the transformers package.
-    """
-    # Step 1: Find the block
-    block_regex = re.compile(
-        r"if not is_torchvision_available\(\):\s+raise OptionalDependencyNotAvailable\(\)\s+except OptionalDependencyNotAvailable:\s+from \.utils\.dummy_torchvision_objects import \*\s+else:(?P<else_block>\s*(\n\s*from .+ import .*\n)+)(?=\s*try:\s+if not \(is_torchvision_available\(\) and is_timm_available\(\)\):)",
-        re.DOTALL,
-    )
-    match = block_regex.search(content)
-
-    if match:
-        block_content = match.group("else_block")  # The captured import block
-    else:
-        print("Couldn't find the import statement block.")
-
-    # Step 2: Parse existing entries
-    lines = block_content.strip().split("\n")
-    entries = []
-
-    indent = " " * (len(lines[1]) - len(lines[1].lstrip()))
-    import_structure_header = indent + lines[0]
-    entries = lines[1:]
-
-    # Add the new entry, maintaining alphabetical order
-    new_entry = f"{indent}from .models.{model_name} import {fast_image_processor_name}"
-    if new_entry not in entries:
-        entries.append(new_entry)
-
-    entries.sort()
-    entries = [import_structure_header] + entries
-
-    # Step 3: Reconstruct the block
-    updated_block = "\n".join(entry for entry in entries)
-
-    # Replace the original block in the content
-    updated_content = (
-        content[: match.start("else_block")] + "\n" + updated_block + "\n\n" + content[match.end("else_block") :]
-    )
-
-    return updated_content
-
-
-def add_fast_image_processor_to_main_init(fast_image_processor_name: str, model_name: str):
-    """
-    Add the fast image processor to the main __init__.py file of the transformers package.
-    """
-    with open(TRANSFORMERS_PATH / "__init__.py", "r", encoding="utf-8") as f:
-        content = f.read()
-
-    # add _import_structure entry
-    content = add_import_structure_entry_init(content, fast_image_processor_name, model_name)
-    # add import statement
-    content = add_import_statement_init(content, fast_image_processor_name, model_name)
-
-    # write the updated content
-    with open(TRANSFORMERS_PATH / "__init__.py", "w", encoding="utf-8") as f:
-        f.write(content)
-
-
 def add_fast_image_processor_to_model_init(
     fast_image_processing_module_file: str, fast_image_processor_name, model_name: str
 ):
@@ -265,40 +163,6 @@ def add_fast_image_processor_to_auto(image_processor_name: str, fast_image_proce
         f.write(updated_content)
 
 
-def add_fast_image_processor_to_dummy(fast_image_processor_name: str):
-    """
-    Add the fast image processor to the dummy torchvision objects file.
-    """
-    dummy_torchvision_objects_file = TRANSFORMERS_PATH / "utils" / "dummy_torchvision_objects.py"
-    with open(dummy_torchvision_objects_file, "r", encoding="utf-8") as f:
-        content = f.read()
-
-    # regex to find objects starting with "class " and ending with "ImageProcessorFast", including "ImageProcessorFast" in the match
-    image_processor_names = re.findall(r"class (\w*ImageProcessorFast)", content)
-    image_processor_names.append(fast_image_processor_name)
-    image_processor_names.sort()
-    index_new = image_processor_names.index(fast_image_processor_name)
-
-    new_dummy_object = (
-        f"class {fast_image_processor_name}(metaclass=DummyObject):\n"
-        '    _backends = ["torchvision"]\n\n'
-        "    def __init__(self, *args, **kwargs):\n"
-        '        requires_backends(self, ["torchvision"])\n'
-    )
-    if new_dummy_object not in content:
-        if index_new != len(image_processor_names) - 1:
-            # add the dummy object just before the next ImageProcessorFast
-            first_line = f"class {image_processor_names[index_new+1]}(metaclass=DummyObject):"
-            updated_content = content.replace(first_line, new_dummy_object + "\n\n" + first_line)
-        else:
-            # add the dummy object at the very end
-            updated_content = content + "\n\n" + new_dummy_object
-
-        # write the updated content
-        with open(dummy_torchvision_objects_file, "w", encoding="utf-8") as f:
-            f.write(updated_content)
-
-
 def add_fast_image_processor_to_doc(fast_image_processor_name: str, model_name: str):
     """
     Add the fast image processor to the model's doc file.
@@ -313,11 +177,9 @@ def add_fast_image_processor_to_doc(fast_image_processor_name: str, model_name:
         raise ValueError(f"No doc files found for {model_name}")
 
     base_doc_string = (
-        f"## {fast_image_processor_name[:-4]}\n\n" f"[[autodoc]] {fast_image_processor_name[:-4]}\n" "    - preprocess"
-    )
-    fast_doc_string = (
-        f"## {fast_image_processor_name}\n\n" f"[[autodoc]] {fast_image_processor_name}\n" "    - preprocess"
+        f"## {fast_image_processor_name[:-4]}\n\n[[autodoc]] {fast_image_processor_name[:-4]}\n    - preprocess"
     )
+    fast_doc_string = f"## {fast_image_processor_name}\n\n[[autodoc]] {fast_image_processor_name}\n    - preprocess"
 
     for doc_file in doc_files:
         with open(doc_file, "r", encoding="utf-8") as f:
@@ -385,7 +247,7 @@ def add_fast_image_processor_to_tests(fast_image_processor_name: str, model_name
     # add the fast image processor to the imports
     base_import_string = f"    from transformers import {fast_image_processor_name[:-4]}"
     fast_import_string = (
-        "    if is_torchvision_available():\n" f"        from transformers import {fast_image_processor_name}"
+        f"    if is_torchvision_available():\n        from transformers import {fast_image_processor_name}"
     )
     if fast_import_string not in updated_content:
         updated_content = updated_content.replace(base_import_string, base_import_string + "\n\n" + fast_import_string)
@@ -534,9 +396,7 @@ def add_fast_image_processor_file(
 
     content_header = get_fast_image_processing_content_header(content_base_file)
     content_base_file = (
-        f"@add_start_docstrings(\n"
-        f'    "Constructs a fast {fast_image_processor_name.replace("ImageProcessorFast", "")} image processor.",\n'
-        f"    BASE_IMAGE_PROCESSOR_FAST_DOCSTRING,\n)\n"
+        f"@auto_docstring\n"
         f"class {fast_image_processor_name}(BaseImageProcessorFast):\n"
         "    # This generated class can be used as a starting point for the fast image processor.\n"
         "    # if the image processor is only used for simple augmentations, such as resizing, center cropping, rescaling, or normalizing,\n"
@@ -546,23 +406,21 @@ def add_fast_image_processor_file(
         "    # For an example of a fast image processor requiring more complex augmentations, see `LlavaNextImageProcessorFast`.\n\n"
         "    # Default values should be checked against the slow image processor\n"
         "    # None values left after checking can be removed\n"
-        f'    resample = {default_args_dict.get("resample")}\n'
-        f'    image_mean = {default_args_dict.get("image_mean")}\n'
-        f'    image_std = {default_args_dict.get("image_std")}\n'
-        f'    size = {default_args_dict.get("size")}\n'
-        f'    default_to_square = {default_args_dict.get("default_to_square")}\n'
-        f'    crop_size = {default_args_dict.get("crop_size")}\n'
-        f'    do_resize = {default_args_dict.get("do_resize")}\n'
-        f'    do_center_crop = {default_args_dict.get("do_center_crop")}\n'
-        f'    do_rescale = {default_args_dict.get("do_rescale")}\n'
-        f'    do_normalize = {default_args_dict.get("do_normalize")}\n'
-        f'    do_convert_rgb = {default_args_dict.get("do_convert_rgb")}\n\n\n'
+        f"    resample = {default_args_dict.get('resample')}\n"
+        f"    image_mean = {default_args_dict.get('image_mean')}\n"
+        f"    image_std = {default_args_dict.get('image_std')}\n"
+        f"    size = {default_args_dict.get('size')}\n"
+        f"    default_to_square = {default_args_dict.get('default_to_square')}\n"
+        f"    crop_size = {default_args_dict.get('crop_size')}\n"
+        f"    do_resize = {default_args_dict.get('do_resize')}\n"
+        f"    do_center_crop = {default_args_dict.get('do_center_crop')}\n"
+        f"    do_rescale = {default_args_dict.get('do_rescale')}\n"
+        f"    do_normalize = {default_args_dict.get('do_normalize')}\n"
+        f"    do_convert_rgb = {default_args_dict.get('do_convert_rgb')}\n\n\n"
         f'__all__ = ["{fast_image_processor_name}"]\n'
     )
 
-    imports = (
-        "\n\nfrom ...image_processing_utils_fast import BASE_IMAGE_PROCESSOR_FAST_DOCSTRING, BaseImageProcessorFast\n"
-    )
+    imports = "\n\nfrom ...image_processing_utils_fast import BaseImageProcessorFast\n"
     image_utils_imports = []
     if default_args_dict.get("resample") is not None and "PILImageResampling" in default_args_dict.get("resample"):
         image_utils_imports.append("PILImageResampling")
@@ -580,7 +438,7 @@ def add_fast_image_processor_file(
         image_utils_imports.sort()
         imports += f"from ...image_utils import {', '.join(image_utils_imports)}\n"
 
-    imports += "from ...utils import add_start_docstrings\n"
+    imports += "from ...utils import auto_docstring\n"
 
     content = content_header + imports + "\n\n" + content_base_file
 
@@ -621,11 +479,6 @@ def add_fast_image_processor(model_name: str):
 
     print(f"Adding {fast_image_processor_name} to {fast_image_processing_module_file}")
 
-    add_fast_image_processor_to_main_init(
-        fast_image_processor_name=fast_image_processor_name,
-        model_name=model_name,
-    )
-
     add_fast_image_processor_to_model_init(
         fast_image_processing_module_file=fast_image_processing_module_file,
         fast_image_processor_name=fast_image_processor_name,
@@ -637,8 +490,6 @@ def add_fast_image_processor(model_name: str):
         fast_image_processor_name=fast_image_processor_name,
     )
 
-    add_fast_image_processor_to_dummy(fast_image_processor_name=fast_image_processor_name)
-
     add_fast_image_processor_to_doc(
         fast_image_processor_name=fast_image_processor_name,
         model_name=model_name,
