@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2024 HuggingFace Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -78,58 +77,6 @@ class RopeTest(unittest.TestCase):
                     self.assertEqual(len(logs.output), 1)
                     self.assertIn(model_specific_kwarg, logs.output[0])
 
-    def test_default_rope_function_bc(self):
-        config = LlamaConfig()
-        device = torch_device
-
-        rope_kwargs = {
-            "rope_type": "default",
-            "dim": config.hidden_size // config.num_attention_heads,
-            "max_position_embeddings": config.max_position_embeddings,
-            "base": config.rope_theta,
-        }
-
-        rope_fn = ROPE_INIT_FUNCTIONS["default"]
-        config_freqs = rope_fn(config=config, device=device)[0]
-        kwargs_freqs = rope_fn(**rope_kwargs, device=device)[0]
-        torch.testing.assert_close(config_freqs, kwargs_freqs)
-
-    def test_linear_rope_function_bc(self):
-        config = LlamaConfig()
-        config.rope_scaling = {"rope_type": "linear", "factor": 10.0}
-        device = torch_device
-
-        rope_kwargs = {
-            "rope_type": "linear",
-            "dim": config.hidden_size // config.num_attention_heads,
-            "max_position_embeddings": config.max_position_embeddings,
-            "base": config.rope_theta,
-            "factor": 10.0,
-        }
-
-        rope_fn = ROPE_INIT_FUNCTIONS["linear"]
-        config_freqs = rope_fn(config=config, device=device)[0]
-        kwargs_freqs = rope_fn(**rope_kwargs, device=device)[0]
-        torch.testing.assert_close(config_freqs, kwargs_freqs)
-
-    def test_dynamic_rope_function_bc(self):
-        config = LlamaConfig()
-        config.rope_scaling = {"rope_type": "dynamic", "factor": 10.0}
-        device = torch_device
-
-        rope_kwargs = {
-            "rope_type": "dynamic",
-            "dim": config.hidden_size // config.num_attention_heads,
-            "max_position_embeddings": config.max_position_embeddings,
-            "base": config.rope_theta,
-            "factor": 10.0,
-        }
-
-        rope_fn = ROPE_INIT_FUNCTIONS["dynamic"]
-        config_freqs = rope_fn(config=config, device=device)[0]
-        kwargs_freqs = rope_fn(**rope_kwargs, device=device)[0]
-        torch.testing.assert_close(config_freqs, kwargs_freqs)
-
     def test_default_rope_numerically(self):
         # Note: some RoPE scaling methods start off by calling the default RoPE frequencies. If this test fails, then
         # multiple RoPE strategies will fail.
@@ -221,6 +168,9 @@ class RopeTest(unittest.TestCase):
             inv_freq, _ = rope_fn(config=config, device=torch_device, seq_len=1)
             torch.testing.assert_close(inv_freq, default_inv_freq)
 
+            inv_freq, _ = rope_fn(config=config, device=torch_device, seq_len=torch.tensor(1, dtype=torch.int64))
+            torch.testing.assert_close(inv_freq, default_inv_freq)
+
         # Check 2: if we provide `seq_len` larger than the model's original training sequence length, the frequencies
         # will scale up (i.e., the inverse frequencies will scale down).
         factor = 10.0
